@@ -319,7 +319,7 @@ class ShopApi(BaseApi):
         }
 
         _request = self.config.http_client.patch(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
-        OAuth2.apply(config, http_request)
+        OAuth2.apply(config, _request)
         _response = self.execute_request(_request)
 
         decoded = ApiHelper.json_deserialize(_response.text)
@@ -343,7 +343,7 @@ class ShopApi(BaseApi):
         }
 
         _request = self.config.http_client.put(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
-        OAuth2.apply(self.config, http_request)
+        OAuth2.apply(self.config, _request)
         _response = self.execute_request(_request)
 
         decoded = ApiHelper.json_deserialize(_response.text)
@@ -369,20 +369,6 @@ class ShopApi(BaseApi):
         OAuth2.apply(self.config, _request)
         _response = self.execute_request(_request)
 
-        _url_path = f'/shop/hour/{hour_id}'
-        _query_builder = self.config.get_base_uri()
-        _query_builder += _url_path 
-        _query_url = ApiHelper.clean_url(_query_builder)
-
-        _headers = { 
-            'accept': 'application/json', 
-            'Content-Type': 'application/json'
-        }
-
-        _request = self.config.http_client.patch(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
-        OAuth2.apply(config, http_request)
-        _response = self.execute_request(_request)
-
         decoded = ApiHelper.json_deserialize(_response.text)
         if type(decoded) == dict: 
             _errors = decoded.get('error')
@@ -404,7 +390,7 @@ class ShopApi(BaseApi):
         }
 
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
-        OAuth2.apply(self.config, http_request)
+        OAuth2.apply(self.config, _request)
         _response = self.execute_request(_request)
 
         decoded = ApiHelper.json_deserialize(_response.text)
@@ -428,7 +414,7 @@ class ShopApi(BaseApi):
         }
 
         _request = self.config.http_client.delete(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
-        OAuth2.apply(self.config, http_request)
+        OAuth2.apply(self.config, _request)
         _response = self.execute_request(_request)
 
         decoded = ApiHelper.json_deserialize(_response.text)
