@@ -10,6 +10,7 @@ from .apis.option_api import OptionApi
 from .apis.item_api import ItemApi
 from .apis.modifier_api import ModifierApi
 from .apis.category_api import CategoryApi
+from .apis.notification_api import NotificationApi
 
 class Client: 
 
@@ -66,6 +67,10 @@ class Client:
     def option(self):
         return OptionApi(self.config)
 
+    @cached_property
+    def notification(self):
+        return NotificationApi(self.config)
+
 
                 
 
