@@ -5,9 +5,9 @@ from sweetspot.https.http_client import HttpClient
 class Configuration(object): 
 
 	environments = {
-		'development': 'http://merchant-api:5000/api',
-		'production': 'https://sweetspot.so',
-		'test': 'http://localhost:5000/api'
+		'development': 'http://merchant-api:5000/api/merchant',
+		'production': 'https://sweetspot.so/api/merchant',
+		'test': 'http://localhost:5000/api/merchant'
 	}
 
 	def __init__(self, csrf_access_token=None, 
